@@ -26,12 +26,15 @@ from manilaclient import client as manila_client
 import six
 
 from horizon import exceptions
+from horizon.utils.memoized import memoized  # noqa
 from openstack_dashboard.api import base
+from openstack_dashboard.api import nova
+
 
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.15"  # requires manilaclient 1.8.0 or newer
+MANILA_VERSION = "2.22"  # requires manilaclient 1.10.0 or newer
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -63,6 +66,7 @@ def manilaclient(request):
     )
     c.client.auth_token = request.user.token.id
     c.client.management_url = manila_url
+
     return c
 
 
@@ -135,6 +139,33 @@ def share_manage(request, service_host, protocol, export_path,
     )
 
 
+def migration_start(request, share, dest_host, force_host_assisted_migration,
+                    writable, preserve_metadata, nondisruptive,
+                    new_share_network_id, new_share_type_id):
+    return manilaclient(request).shares.migration_start(
+        share,
+        host=dest_host,
+        force_host_assisted_migration=force_host_assisted_migration,
+        writable=writable,
+        preserve_metadata=preserve_metadata,
+        nondisruptive=nondisruptive,
+        new_share_network_id=new_share_network_id,
+        new_share_type_id=new_share_type_id
+    )
+
+
+def migration_complete(request, share):
+    return manilaclient(request).shares.migration_complete(share)
+
+
+def migration_get_progress(request, share):
+    return manilaclient(request).shares.migration_get_progress(share)
+
+
+def migration_cancel(request, share):
+    return manilaclient(request).shares.migration_cancel(share)
+
+
 def share_unmanage(request, share):
     # Param 'share' can be either string with ID or object with attr 'id'.
     return manilaclient(request).shares.unmanage(share)
@@ -336,6 +367,58 @@ def share_type_access_remove(request, share_type_id, project_id):
         share_type_id, project_id)
 
 
+def share_replica_list(request, share=None):
+    return manilaclient(request).share_replicas.list(share)
+
+
+def share_replica_create(request, share, availability_zone,
+                         share_network=None):
+    return manilaclient(request).share_replicas.create(
+        share,
+        availability_zone=availability_zone,
+        share_network=share_network)
+
+
+def share_replica_get(request, replica):
+    return manilaclient(request).share_replicas.get(replica)
+
+
+def share_replica_delete(request, replica):
+    return manilaclient(request).share_replicas.delete(replica)
+
+
+def share_replica_promote(request, replica):
+    return manilaclient(request).share_replicas.promote(replica)
+
+
+def share_replica_reset_status(request, replica, status):
+    return manilaclient(request).share_replicas.reset_state(
+        replica, status)
+
+
+def share_replica_reset_state(request, replica, state):
+    return manilaclient(request).share_replicas.reset_replica_state(
+        replica, state)
+
+
+def share_replica_resync(request, replica):
+    return manilaclient(request).share_replicas.resync(replica)
+
+
+def share_valid_availability_zones_for_new_replica(request, share):
+    availability_zones = (
+        set([az.zoneName
+             for az in nova.availability_zone_list(request)])
+    )
+
+    az_with_replicas = (
+        set([r.availability_zone
+             for r in share_replica_list(request, share)])
+    )
+
+    return availability_zones - az_with_replicas
+
+
 def tenant_absolute_limits(request):
     limits = manilaclient(request).limits.get().absolute
     limits_dict = {}
@@ -354,3 +437,15 @@ def share_instance_list(request):
 
 def share_instance_get(request, share_instance_id):
     return manilaclient(request).share_instances.get(share_instance_id)
+
+
+@memoized
+def is_replication_enabled():
+    manila_config = getattr(settings, 'OPENSTACK_MANILA_FEATURES', {})
+    return manila_config.get('enable_replication', True)
+
+
+@memoized
+def is_migration_enabled():
+    manila_config = getattr(settings, 'OPENSTACK_MANILA_FEATURES', {})
+    return manila_config.get('enable_migration', True)
