@@ -17,7 +17,7 @@
 #    under the License.
 
 from django.core.urlresolvers import reverse
-from manilaclient import exceptions as manila_client_exc
+from horizon import exceptions as horizon_exceptions
 import mock
 
 from manila_ui.api import manila as api_manila
@@ -33,6 +33,7 @@ SHARE_INDEX_URL = reverse('horizon:project:shares:index')
 class SecurityServicesViewTests(test.TestCase):
 
     def test_create_security_service(self):
+        sec_service = test_data.sec_service
         formData = {
             'name': u'new_sec_service',
             'description': u'This is test security service',
@@ -46,7 +47,9 @@ class SecurityServicesViewTests(test.TestCase):
             'server': 'testserver',
         }
         url = reverse('horizon:project:shares:create_security_service')
-        self.mock_object(api_manila, "security_service_create")
+        self.mock_object(
+            api_manila, "security_service_create",
+            mock.Mock(return_value=sec_service))
 
         res = self.client.post(url, formData)
 
@@ -105,7 +108,7 @@ class SecurityServicesViewTests(test.TestCase):
                       args=[test_data.sec_service.id])
         self.mock_object(
             api_manila, "security_service_get",
-            mock.Mock(side_effect=manila_client_exc.NotFound(404)))
+            mock.Mock(side_effect=horizon_exceptions.NotFound(404)))
 
         res = self.client.get(url)
 
